@@ -1,16 +1,18 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
-#ifndef GRANTLEETHEMEMANAGER_H
-#define GRANTLEETHEMEMANAGER_H
+#pragma once
 
 #include "grantleetheme.h"
 #include "grantleetheme_export.h"
 #include <QMap>
 #include <QObject>
+
+#include <memory>
+
 class QActionGroup;
 class KActionCollection;
 class KToggleAction;
@@ -18,6 +20,8 @@ class KActionMenu;
 
 namespace GrantleeTheme
 {
+class ThemeManagerPrivate;
+
 /**
  * @brief The ThemeManager class
  * @author Laurent montel <montel@kde.org>
@@ -30,28 +34,27 @@ public:
                           const QString &defaultDesktopFileName,
                           KActionCollection *actionCollection = nullptr,
                           const QString &path = QString(),
+                          const QString &configFileName = QString(),
                           QObject *parent = nullptr);
-    ~ThemeManager();
+    ~ThemeManager() override;
 
-    Q_REQUIRED_RESULT QMap<QString, GrantleeTheme::Theme> themes() const;
+    [[nodiscard]] QMap<QString, GrantleeTheme::Theme> themes() const;
 
     void setActionGroup(QActionGroup *actionGroup);
 
-    Q_REQUIRED_RESULT KToggleAction *actionForTheme();
+    [[nodiscard]] KToggleAction *actionForTheme();
 
     void setThemeMenu(KActionMenu *menu);
 
-    Q_REQUIRED_RESULT QStringList displayExtraVariables(const QString &themename) const;
+    [[nodiscard]] QStringList displayExtraVariables(const QString &themename) const;
 
-    Q_REQUIRED_RESULT GrantleeTheme::Theme theme(const QString &themeName);
+    [[nodiscard]] GrantleeTheme::Theme theme(const QString &themeName);
 
-    void setDownloadNewStuffConfigFile(const QString &configFileName);
+    [[nodiscard]] QString configuredThemeName() const;
+    [[nodiscard]] static QString configuredThemeName(const QString &themeType);
 
-    Q_REQUIRED_RESULT QString configuredThemeName() const;
-    Q_REQUIRED_RESULT static QString configuredThemeName(const QString &themeType);
-
-    Q_REQUIRED_RESULT static QString pathFromThemes(const QString &path, const QString &themeName, const QString &defaultDesktopFilename);
-    Q_REQUIRED_RESULT static GrantleeTheme::Theme loadTheme(const QString &themePath, const QString &dirName, const QString &defaultDesktopFilename);
+    [[nodiscard]] static QString pathFromThemes(const QString &path, const QString &themeName, const QString &defaultDesktopFilename);
+    [[nodiscard]] static GrantleeTheme::Theme loadTheme(const QString &themePath, const QString &dirName, const QString &defaultDesktopFilename);
 
 Q_SIGNALS:
     void themesChanged();
@@ -59,9 +62,8 @@ Q_SIGNALS:
     void updateThemes();
 
 private:
-    class Private;
-    Private *const d;
+    friend class ThemeManagerPrivate;
+    std::unique_ptr<ThemeManagerPrivate> const d;
     Q_PRIVATE_SLOT(d, void directoryChanged())
 };
 }
-#endif // GRANTLEETHEMEMANAGER_H
